@@ -52,7 +52,7 @@ from .common import IS_CYGWIN, IS_MSYS, IS_WSL, ERROR_SUCCESS, \
     PFILETIME, SUBLANG_DEFAULT
 
 ## Numeric version
-__numversion__ = (0, 5, 0)
+__numversion__ = (0, 9, 0)
 
 ## Current version of the library
 __version__ = '.'.join([str(num) for num in __numversion__])
@@ -86,12 +86,16 @@ if IS_CYGWIN or IS_MSYS:
         DeleteKey, DeleteKeyEx, DeleteValue, EnumKey, EnumValue, \
         ExpandEnvironmentStrings, FlushKey, LoadKey, OpenKey, OpenKeyEx, \
         QueryInfoKey, QueryValue, QueryValueEx, SaveKey, SetValue, SetValueEx, \
-        DisableReflectionKey, EnableReflectionKey,QueryReflectionKey
+        DisableReflectionKey, EnableReflectionKey, QueryReflectionKey
 elif IS_WSL:
-    from .wslapi import *
+    from .wslapi import CloseKey, ConnectRegistry, CreateKey, CreateKeyEx, \
+        DeleteKey, DeleteKeyEx, DeleteValue, EnumKey, EnumValue, \
+        ExpandEnvironmentStrings, FlushKey, LoadKey, OpenKey, OpenKeyEx, \
+        QueryInfoKey, QueryValue, QueryValueEx, SaveKey, SetValue, SetValueEx, \
+        DisableReflectionKey, EnableReflectionKey, QueryReflectionKey
 else:
     from .nullapi import CloseKey, ConnectRegistry, CreateKey, CreateKeyEx, \
         DeleteKey, DeleteKeyEx, DeleteValue, EnumKey, EnumValue, \
         ExpandEnvironmentStrings, FlushKey, LoadKey, OpenKey, OpenKeyEx, \
         QueryInfoKey, QueryValue, QueryValueEx, SaveKey, SetValue, SetValueEx, \
-        DisableReflectionKey, EnableReflectionKey,QueryReflectionKey
+        DisableReflectionKey, EnableReflectionKey, QueryReflectionKey
